type SpacingType = undefined | string | number | {
    b?: number;
    l?: number;
    r?: number;
    t?: number;
};
/**
 * Custom spacing for a component.
 * @example
 * ```tsx
 * <Button spacing={{ b: 2, l: 1, r: 1, t: 2 }}>Hello World</Button>
 * <Button spacing="2">Hello World</Button>
 * <Button spacing={2}>Hello World</Button>
 * ```
 */
type SpacingProps = {
    spacing?: SpacingType;
};
/**
 * This method returns a string that can be used as a tailwind class relying
 * on margins definitions (m, mt, mb, etc.).
 * Please refer to: https://tailwindcss.com/docs/margin
 *
 * It accepts a number, a string or an object.
 * If a number is passed, it will be converted to a string and prefixed with "m-".
 * If a string is passed, it will be prefixed with "m-".
 * If an object is passed, it will be converted to a string like this:
 * { t: 4, r: 1, b: 3, l: 5} => "mt-4 mr-1 mb-3 ml-5"
 *
 */
declare const getSpacing: (spacing: SpacingType) => string;

export { type SpacingProps, type SpacingType, getSpacing };
